summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorZhang Xianwei <[email protected]>2018-11-26 14:07:43 +0800
committerraveit65 <[email protected]>2018-11-27 13:50:14 +0100
commit2c2f966a9cf902890519ef0d727a8b0fedc89654 (patch)
treec57d2a633b609964e063ac1ab297803a6b44b2a3
parenta7b4e6ca71a38e29edc830be0e34e5f0273cb620 (diff)
downloadmate-power-manager-2c2f966a9cf902890519ef0d727a8b0fedc89654.tar.bz2
mate-power-manager-2c2f966a9cf902890519ef0d727a8b0fedc89654.tar.xz
osd-window: make the window smaller
Matches the gnome's mockups better. Signed-off-by: Zhang Xianwei <[email protected]>
-rw-r--r--src/msd-osd-window.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/msd-osd-window.c b/src/msd-osd-window.c
index 7797a3b..be44c14 100644
--- a/src/msd-osd-window.c
+++ b/src/msd-osd-window.c
@@ -457,11 +457,11 @@ msd_osd_window_init (MsdOsdWindow *window)
GtkStyleContext *style = gtk_widget_get_style_context (GTK_WIDGET (window));
gtk_style_context_add_class (style, "window-frame");
/* assume 130x130 on a 640x480 display and scale from there */
scalew = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / (640.0 * window->priv->scale_factor);
scaleh = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / (480.0 * window->priv->scale_factor);
scale = MIN (scalew, scaleh);
- size = 130 * MAX (1, scale);
+ size = 110 * MAX (1, scale);
gtk_window_set_default_size (GTK_WINDOW (window), size, size);
@@ -457,11 +457,11 @@ msd_osd_window_init (MsdOsdWindow *window)
GtkStyleContext *style = gtk_widget_get_style_context (GTK_WIDGET (window));
gtk_style_context_add_class (style, "window-frame");
- /* assume 130x130 on a 640x480 display and scale from there */
+ /* assume 110x110 on a 640x480 display and scale from there */
scalew = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / (640.0 * window->priv->scale_factor);
scaleh = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / (480.0 * window->priv->scale_factor);